Trees
=====

.. automodule:: anhima.tree
.. autofunction:: nj
.. autofunction:: bionj
.. autofunction:: read_tree
.. autofunction:: write_tree
.. autofunction:: plot_phylo
.. autofunction:: color_edges_by_group_majority









